==> qtjambi-debuginfo-macos-5.15.18.jar: sources/QtJambiGui/QInputMethodQueryEvent_shell.cpp <==
#include "QInputMethodQueryEvent_shell.h"
#include <QtJambi/Cast>

void deleter_QInputMethodQueryEvent(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QInputMethodQueryEvent")
    QInputMethodQueryEvent *_ptr = reinterpret_cast<QInputMethodQueryEvent *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

QtJambiShell* QInputMethodQueryEvent_shell::__shell() const { return *reinterpret_cast<QtJambiShell**>( quintptr(this) + sizeof(QInputMethodQueryEvent_shell) ); }

jmethodID QInputMethodQueryEvent_shell::__shell_javaMethod(int pos) const { return QInputMethodQueryEvent_shell::__shell()->javaMethod(typeid(QInputMethodQueryEvent), pos); }

// emitting (writeShellConstructor)
QInputMethodQueryEvent_shell::QInputMethodQueryEvent_shell(Qt::InputMethodQueries queries0)
    : QInputMethodQueryEvent(queries0)
{
    QTJAMBI_IN_CONSTRUCTOR_CALL("QInputMethodQueryEvent::QInputMethodQueryEvent_shell(Qt::InputMethodQueries queries0)", QInputMethodQueryEvent_shell::__shell())
    QInputMethodQueryEvent_shell::__shell()->constructed(typeid(QInputMethodQueryEvent));
}

// emitting (writeShellDestructor)
QInputMethodQueryEvent_shell::~QInputMethodQueryEvent_shell()
{
    QTJAMBI_IN_DESTRUCTOR_CALL("QInputMethodQueryEvent::~QInputMethodQueryEvent()", QInputMethodQueryEvent_shell::__shell())
    QInputMethodQueryEvent_shell::__shell()->destructed(typeid(QInputMethodQueryEvent));
}

void QInputMethodQueryEvent_shell::operator delete(void * ptr) noexcept {
    reinterpret_cast<QInputMethodQueryEvent_shell*>(ptr)->QInputMethodQueryEvent_shell::__shell()->tryDeleteShell(typeid(QInputMethodQueryEvent));
}

// emitting Virtual overrides (virtualFunctions)
// emitting Functions in shell class (nonVirtualShellFunctions)
// emitting Public Override Functions (publicOverrideFunctions)
// emitting Virtual Override Functions (virtualOverrideFunctions)
// emitting (writeConstructors)
// new QInputMethodQueryEvent(Qt::InputMethodQueries)
void __qt_construct_QInputMethodQueryEvent_0(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QInputMethodQueryEvent(Qt::InputMethodQueries)")
    jobject queries0 = __java_arguments[0].l;
    Qt::InputMethodQueries __qt_queries0 = qtjambi_cast<Qt::InputMethodQueries>(__jni_env, queries0);
    QInputMethodQueryEvent *__qt_this = new(__qtjambi_ptr) QInputMethodQueryEvent_shell(Qt::InputMethodQueries(__qt_queries0));
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
}

// destruct QInputMethodQueryEvent_shell
void __qt_destruct_QInputMethodQueryEvent(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QInputMethodQueryEvent")
    reinterpret_cast<QInputMethodQueryEvent_shell*>(ptr)->~QInputMethodQueryEvent_shell();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QInputMethodQueryEvent::QInputMethodQueryEvent(Qt::InputMethodQueries)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QInputMethodQueryEvent_initialize_1native__Lio_qt_gui_QInputMethodQueryEvent_2Lio_qt_core_Qt_00024InputMethodQueries_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject queries0)
{
    QTJAMBI_NATIVE_METHOD_CALL("QInputMethodQueryEvent::QInputMethodQueryEvent(Qt::InputMethodQueries)")
    QTJAMBI_TRY {
        jvalue arguments;
        arguments.l = queries0;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QInputMethodQueryEvent_0, sizeof(QInputMethodQueryEvent_shell), typeid(QInputMethodQueryEvent), true, &deleter_QInputMethodQueryEvent, &arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QInputMethodQueryEvent::queries()const
extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QInputMethodQueryEvent_queries_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jint __java_return_value{0};
    QTJAMBI_TRY {
        const QInputMethodQueryEvent *__qt_this = QtJambiAPI::objectFromNativeId<QInputMethodQueryEvent>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QInputMethodQueryEvent::queries()const", __qt_this)
        Qt::InputMethodQueries __qt_return_value = __qt_this->queries();
        __java_return_value = __qt_return_value;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QInputMethodQueryEvent::setValue(Qt::InputMethodQuery,QVariant)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QInputMethodQueryEvent_setValue_1native_1Qt_1InputMethodQuery_1cref_1QVariant__JILjava_lang_Object_2)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jint query0,
 jobject value1)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QInputMethodQueryEvent *__qt_this = QtJambiAPI::objectFromNativeId<QInputMethodQueryEvent>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QInputMethodQueryEvent::setValue(Qt::InputMethodQuery,QVariant)", __qt_this)
        Qt::InputMethodQuery __qt_query0 = qtjambi_cast<Qt::InputMethodQuery>(__jni_env, query0);
        QVariant  __qt_value1 = qtjambi_cast<QVariant >(__jni_env, value1);
        __qt_this->setValue(Qt::InputMethodQuery(__qt_query0), __qt_value1);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QInputMethodQueryEvent::value(Qt::InputMethodQuery)const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QInputMethodQueryEvent_value_1native_1Qt_1InputMethodQuery_1constfct__JI)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jint query0)
{
    Q_UNUSED(__this)
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        const QInputMethodQueryEvent *__qt_this = QtJambiAPI::objectFromNativeId<QInputMethodQueryEvent>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QInputMethodQueryEvent::value(Qt::InputMethodQuery)const", __qt_this)
        Qt::InputMethodQuery __qt_query0 = qtjambi_cast<Qt::InputMethodQuery>(__jni_env, query0);
        QVariant __qt_return_value = __qt_this->value(Qt::InputMethodQuery(__qt_query0));
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// emitting (writeJavaLangObjectOverrideFunctions)
// emitting (writeCloneFunction)

extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QInputMethodQueryEvent_clone_1native)
(JNIEnv *__jni_env, jobject, QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value = nullptr;
    QTJAMBI_TRY {
        const QInputMethodQueryEvent *__qt_this = QtJambiAPI::objectFromNativeId<QInputMethodQueryEvent>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __java_return_value = QtJambiAPI::convertNativeToJavaOwnedObjectAsWrapper(__jni_env, new QInputMethodQueryEvent(*__qt_this));
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}


void initialize_meta_info_QInputMethodQueryEvent(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerObjectTypeInfo<QInputMethodQueryEvent>("QInputMethodQueryEvent", "io/qt/gui/QInputMethodQueryEvent");
// BEGIN: function table
    registerConstructorInfos(typeId, &__qt_destruct_QInputMethodQueryEvent, {
        ConstructorInfo(&__qt_construct_QInputMethodQueryEvent_0, "Lio/qt/core/Qt$InputMethodQueries;")
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QInputMethodQueryEvent);
    registerSizeOfShell(typeId, sizeof(QInputMethodQueryEvent_shell));
// END: type registration

// BEGIN: polymorphic ids
    registerDefaultPolymorphyHandler<QEvent, QInputMethodQueryEvent>();
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}

==> qtjambi-debuginfo-macos-5.15.19.jar: sources/QtJambiGui/QInputMethodQueryEvent_shell.cpp <==
#include "QInputMethodQueryEvent_shell.h"
#include <QtJambi/Cast>

void deleter_QInputMethodQueryEvent(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QInputMethodQueryEvent")
    QInputMethodQueryEvent *_ptr = reinterpret_cast<QInputMethodQueryEvent *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

QtJambiShell* QInputMethodQueryEvent_shell::__shell() const { return *reinterpret_cast<QtJambiShell**>( quintptr(this) + sizeof(QInputMethodQueryEvent_shell) ); }

jmethodID QInputMethodQueryEvent_shell::__shell_javaMethod(int pos) const { return QInputMethodQueryEvent_shell::__shell()->javaMethod(typeid(QInputMethodQueryEvent), pos); }

// emitting (writeShellConstructor)
QInputMethodQueryEvent_shell::QInputMethodQueryEvent_shell(const QInputMethodQueryEvent& other0)
    : QInputMethodQueryEvent(other0)
{
    QTJAMBI_IN_CONSTRUCTOR_CALL("QInputMethodQueryEvent::QInputMethodQueryEvent_shell(const QInputMethodQueryEvent& other0)", QInputMethodQueryEvent_shell::__shell())
    QInputMethodQueryEvent_shell::__shell()->constructed(typeid(QInputMethodQueryEvent));
}

QInputMethodQueryEvent_shell::QInputMethodQueryEvent_shell(Qt::InputMethodQueries queries0)
    : QInputMethodQueryEvent(queries0)
{
    QTJAMBI_IN_CONSTRUCTOR_CALL("QInputMethodQueryEvent::QInputMethodQueryEvent_shell(Qt::InputMethodQueries queries0)", QInputMethodQueryEvent_shell::__shell())
    QInputMethodQueryEvent_shell::__shell()->constructed(typeid(QInputMethodQueryEvent));
}

// emitting (writeShellDestructor)
QInputMethodQueryEvent_shell::~QInputMethodQueryEvent_shell()
{
    QTJAMBI_IN_DESTRUCTOR_CALL("QInputMethodQueryEvent::~QInputMethodQueryEvent()", QInputMethodQueryEvent_shell::__shell())
    QInputMethodQueryEvent_shell::__shell()->destructed(typeid(QInputMethodQueryEvent));
}

void QInputMethodQueryEvent_shell::operator delete(void * ptr) noexcept {
    reinterpret_cast<QInputMethodQueryEvent_shell*>(ptr)->QInputMethodQueryEvent_shell::__shell()->tryDeleteShell(typeid(QInputMethodQueryEvent));
}

// emitting Virtual overrides (virtualFunctions)
// emitting Functions in shell class (nonVirtualShellFunctions)
// emitting Public Override Functions (publicOverrideFunctions)
// emitting Virtual Override Functions (virtualOverrideFunctions)
// emitting (writeConstructors)
// new QInputMethodQueryEvent(QInputMethodQueryEvent)
void __qt_construct_QInputMethodQueryEvent_cref_QInputMethodQueryEvent(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QInputMethodQueryEvent(QInputMethodQueryEvent)")
    jobject other0 = __java_arguments[0].l;
    const QInputMethodQueryEvent& __qt_other0 = qtjambi_cast<const QInputMethodQueryEvent& >(__jni_env, other0);
    QInputMethodQueryEvent *__qt_this = new(__qtjambi_ptr) QInputMethodQueryEvent_shell(__qt_other0);
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
}

// QInputMethodQueryEvent::QInputMethodQueryEvent(QInputMethodQueryEvent)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QInputMethodQueryEvent_initialize_1native__Lio_qt_gui_QInputMethodQueryEvent_2Lio_qt_gui_QInputMethodQueryEvent_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject other0)
{
    QTJAMBI_NATIVE_METHOD_CALL("QInputMethodQueryEvent::QInputMethodQueryEvent(QInputMethodQueryEvent)")
    QTJAMBI_TRY {
        jvalue arguments;
        arguments.l = other0;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QInputMethodQueryEvent_cref_QInputMethodQueryEvent, sizeof(QInputMethodQueryEvent_shell), typeid(QInputMethodQueryEvent), true, &deleter_QInputMethodQueryEvent, &arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// new QInputMethodQueryEvent(Qt::InputMethodQueries)
void __qt_construct_QInputMethodQueryEvent_Qt_InputMethodQueries(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QInputMethodQueryEvent(Qt::InputMethodQueries)")
    jobject queries0 = __java_arguments[0].l;
    Qt::InputMethodQueries __qt_queries0 = qtjambi_cast<Qt::InputMethodQueries>(__jni_env, queries0);
    QInputMethodQueryEvent *__qt_this = new(__qtjambi_ptr) QInputMethodQueryEvent_shell(Qt::InputMethodQueries(__qt_queries0));
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
}

// QInputMethodQueryEvent::QInputMethodQueryEvent(Qt::InputMethodQueries)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QInputMethodQueryEvent_initialize_1native__Lio_qt_gui_QInputMethodQueryEvent_2Lio_qt_core_Qt_00024InputMethodQueries_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject queries0)
{
    QTJAMBI_NATIVE_METHOD_CALL("QInputMethodQueryEvent::QInputMethodQueryEvent(Qt::InputMethodQueries)")
    QTJAMBI_TRY {
        jvalue arguments;
        arguments.l = queries0;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QInputMethodQueryEvent_Qt_InputMethodQueries, sizeof(QInputMethodQueryEvent_shell), typeid(QInputMethodQueryEvent), true, &deleter_QInputMethodQueryEvent, &arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// destruct QInputMethodQueryEvent_shell
void __qt_destruct_QInputMethodQueryEvent(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QInputMethodQueryEvent")
    reinterpret_cast<QInputMethodQueryEvent_shell*>(ptr)->~QInputMethodQueryEvent_shell();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QInputMethodQueryEvent::queries()const
extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QInputMethodQueryEvent_queries_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jint __java_return_value{0};
    QTJAMBI_TRY {
        const QInputMethodQueryEvent *__qt_this = QtJambiAPI::objectFromNativeId<QInputMethodQueryEvent>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QInputMethodQueryEvent::queries()const", __qt_this)
        Qt::InputMethodQueries __qt_return_value = __qt_this->queries();
        __java_return_value = __qt_return_value;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QInputMethodQueryEvent::setValue(Qt::InputMethodQuery,QVariant)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QInputMethodQueryEvent_setValue_1native_1Qt_1InputMethodQuery_1cref_1QVariant__JILjava_lang_Object_2)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jint query0,
 jobject value1)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QInputMethodQueryEvent *__qt_this = QtJambiAPI::objectFromNativeId<QInputMethodQueryEvent>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QInputMethodQueryEvent::setValue(Qt::InputMethodQuery,QVariant)", __qt_this)
        Qt::InputMethodQuery __qt_query0 = qtjambi_cast<Qt::InputMethodQuery>(__jni_env, query0);
        QVariant  __qt_value1 = qtjambi_cast<QVariant >(__jni_env, value1);
        __qt_this->setValue(Qt::InputMethodQuery(__qt_query0), __qt_value1);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QInputMethodQueryEvent::value(Qt::InputMethodQuery)const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QInputMethodQueryEvent_value_1native_1Qt_1InputMethodQuery_1constfct__JI)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jint query0)
{
    Q_UNUSED(__this)
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        const QInputMethodQueryEvent *__qt_this = QtJambiAPI::objectFromNativeId<QInputMethodQueryEvent>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QInputMethodQueryEvent::value(Qt::InputMethodQuery)const", __qt_this)
        Qt::InputMethodQuery __qt_query0 = qtjambi_cast<Qt::InputMethodQuery>(__jni_env, query0);
        QVariant __qt_return_value = __qt_this->value(Qt::InputMethodQuery(__qt_query0));
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// emitting (writeJavaLangObjectOverrideFunctions)
// emitting (writeCloneFunction)

extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QInputMethodQueryEvent_clone_1native)
(JNIEnv *__jni_env, jobject, QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value = nullptr;
    QTJAMBI_TRY {
        const QInputMethodQueryEvent *__qt_this = QtJambiAPI::objectFromNativeId<QInputMethodQueryEvent>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __java_return_value = QtJambiAPI::convertNativeToJavaOwnedObjectAsWrapper(__jni_env, new QInputMethodQueryEvent(*__qt_this));
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}


void initialize_meta_info_QInputMethodQueryEvent(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerObjectTypeInfo<QInputMethodQueryEvent>("QInputMethodQueryEvent", "io/qt/gui/QInputMethodQueryEvent");
// BEGIN: function table
    registerConstructorInfos(typeId, &__qt_destruct_QInputMethodQueryEvent, {
        ConstructorInfo(&__qt_construct_QInputMethodQueryEvent_cref_QInputMethodQueryEvent, "Lio/qt/gui/QInputMethodQueryEvent;")
       ,ConstructorInfo(&__qt_construct_QInputMethodQueryEvent_Qt_InputMethodQueries, "Lio/qt/core/Qt$InputMethodQueries;")
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QInputMethodQueryEvent);
    registerSizeOfShell(typeId, sizeof(QInputMethodQueryEvent_shell));
// END: type registration

// BEGIN: polymorphic ids
    registerDefaultPolymorphyHandler<QEvent, QInputMethodQueryEvent>();
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}
